==> rc-ui-lib-0.1.35.tgz: package/es/pull-refresh/PullRefresh.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useCallback, useContext, useMemo, useRef } from 'react';
import classnames from 'classnames';
import { getScrollTop, preventDefault } from '../utils';
import useTouch from '../hooks/use-touch';
import { getScrollParent } from '../hooks/use-scroll-parent';
import useEventListener from '../hooks/use-event-listener';
import Loading from '../loading';
import { useSetState, useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var DEFAULT_HEAD_HEIGHT = 50;
var TEXT_STATUS = ['pulling', 'loosing', 'success'];

var PullRefresh = function PullRefresh(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('pull-refresh', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var disabled = props.disabled,
      animationDuration = props.animationDuration;
  var root = useRef();

  var _useSetState = useSetState({
    refreshing: false,
    status: 'normal',
    distance: 0,
    duration: 0
  }),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      state = _useSetState2[0],
      updateState = _useSetState2[1];

  var track = useRef();
  var reachTop = useRef(null);
  var touch = useTouch();

  var getHeadStyle = function getHeadStyle() {
    if (props.headHeight !== DEFAULT_HEAD_HEIGHT) {
      return {
        height: "".concat(props.headHeight, "px")
      };
    }

    return null;
  };

  var isTouchable = useCallback(function () {
    return state.status !== 'loading' && state.status !== 'success' && !disabled;
  }, [state.status, disabled]);

  var ease = function ease(distance) {
    var pullDistance = +(props.pullDistance || props.headHeight);

    if (distance > pullDistance) {
      if (distance < pullDistance * 2) {
        distance = pullDistance + (distance - pullDistance) / 2;
      } else {
        distance = pullDistance * 1.5 + (distance - pullDistance * 2) / 4;
      }
    }

    return Math.round(distance);
  };

  var setStatus = function setStatus(distance, isLoading) {
    var pullDistance = +(props.pullDistance || props.headHeight);
    var newState = {
      distance: distance
    };

    if (isLoading) {
      newState.status = 'loading';
    } else if (distance === 0) {
      newState.status = 'normal';
    } else if (distance < pullDistance) {
      newState.status = 'pulling';
    } else {
      newState.status = 'loosing';
    }

    updateState(newState);
  };

  var getStatusText = function getStatusText() {
    if (state.status === 'normal') {
      return '';
    }

    return props["".concat(state.status, "Text")];
  };

  var renderStatus = function renderStatus() {
    var status = state.status,
        distance = state.distance;

    if (typeof props["".concat(state.status, "Text")] === 'function') {
      return props["".concat(state.status, "Text")]({
        distance: distance
      });
    }

    var nodes = [];

    if (TEXT_STATUS.includes(status)) {
      nodes.push( /*#__PURE__*/React.createElement("div", {
        key: "text",
        className: classnames(bem('text'))
      }, getStatusText()));
    }

    if (status === 'loading') {
      nodes.push( /*#__PURE__*/React.createElement(Loading, {
        key: "loading",
        className: classnames(bem('loading'))
      }, getStatusText()));
    }

    return nodes;
  };

  var showSuccessTip = function showSuccessTip() {
    updateState({
      status: 'success'
    });
    setTimeout(function () {
      setStatus(0);
    }, +props.successDuration);
  };

  var onRefresh = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;
              updateState({
                refreshing: true
              });
              _context.next = 4;
              return props.onRefresh();

            case 4:
              updateState({
                refreshing: false
              });
              _context.next = 10;
              break;

            case 7:
              _context.prev = 7;
              _context.t0 = _context["catch"](0);
              updateState({
                refreshing: false
              });

            case 10:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[0, 7]]);
    }));

    return function onRefresh() {
      return _ref.apply(this, arguments);
    };
  }();

  var checkPosition = function checkPosition(event) {
    var scrollTarget = getScrollParent(event.target);
    reachTop.current = getScrollTop(scrollTarget) === 0;

    if (reachTop.current) {
      updateState({
        duration: 0
      });
      touch.start(event);
    }
  };

  var onTouchStart = function onTouchStart(event) {
    if (isTouchable()) {
      checkPosition(event.nativeEvent);
    }
  };

  var onTouchMove = useCallback(function (event) {
    if (isTouchable()) {
      if (!reachTop.current) {
        checkPosition(event);
      }

      touch.move(event);

      if (reachTop.current && touch.deltaY >= 0 && touch.isVertical()) {
        setStatus(ease(touch.deltaY));
        preventDefault(event);
      } else {
        /**
         * IN THIS CASE:
         * if component don't rerender after event.preventDefault
         * ios will hold `preventDefault` behavior when touchmoving
         * it will cause window unscrollable
         */
        setStatus(0);
      }
    }
  }, [reachTop.current, touch.deltaY, isTouchable]);

  var onTouchEnd = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              if (reachTop.current && touch.deltaY && isTouchable()) {
                updateState({
                  duration: +animationDuration
                });

                if (state.status === 'loosing') {
                  setStatus(+props.headHeight, true);
                  onRefresh();
                } else {
                  setStatus(0);
                }
              }

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    }));

    return function onTouchEnd() {
      return _ref2.apply(this, arguments);
    };
  }();

  useEventListener('touchmove', onTouchMove, {
    target: track.current,
    depends: [reachTop.current, isTouchable(), touch.deltaY]
  });
  useUpdateEffect(function () {
    updateState({
      duration: +animationDuration
    });

    if (state.refreshing) {
      setStatus(+props.headHeight, true);
    } else if (props.successText) {
      showSuccessTip();
    } else {
      setStatus(0, false);
    }
  }, [state.refreshing]);
  var trackStyle = useMemo(function () {
    return {
      transitionDuration: "".concat(state.duration, "ms"),
      transform: state.distance ? "translate3d(0,".concat(state.distance, "px, 0)") : ''
    };
  }, [state.duration, state.distance]);
  return /*#__PURE__*/React.createElement("div", {
    ref: root,
    className: classnames(props.className, bem()),
    style: props.style
  }, /*#__PURE__*/React.createElement("div", {
    ref: track,
    className: classnames(bem('track')),
    style: trackStyle,
    onTouchStart: onTouchStart,
    onTouchEnd: onTouchEnd,
    onTouchCancel: onTouchEnd
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('head')),
    style: getHeadStyle()
  }, renderStatus()), props.children));
};

PullRefresh.defaultProps = {
  headHeight: 50,
  animationDuration: 300,
  successDuration: 500,
  pullingText: '下拉即可刷新...',
  loosingText: '释放即可刷新...',
  loadingText: '加载中...'
};
export default PullRefresh;

==> rc-ui-lib-1.3.4.tgz: package/es/pull-refresh/PullRefresh.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useCallback, useContext, useMemo, useRef } from 'react';
import classnames from 'classnames';
import { getScrollTop, preventDefault } from '../utils';
import { useTouch } from '../hooks/use-touch';
import { getScrollParent } from '../hooks/use-scroll-parent';
import useEventListener from '../hooks/use-event-listener';
import Loading from '../loading';
import { useSetState, useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var DEFAULT_HEAD_HEIGHT = 50;
var TEXT_STATUS = ['pulling', 'loosing', 'success'];

var PullRefresh = function PullRefresh(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('pull-refresh', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var disabled = props.disabled,
      animationDuration = props.animationDuration;
  var root = useRef();

  var _useSetState = useSetState({
    refreshing: false,
    status: 'normal',
    distance: 0,
    duration: 0
  }),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      state = _useSetState2[0],
      updateState = _useSetState2[1];

  var track = useRef();
  var reachTop = useRef(null);
  var touch = useTouch();

  var getHeadStyle = function getHeadStyle() {
    if (props.headHeight !== DEFAULT_HEAD_HEIGHT) {
      return {
        height: "".concat(props.headHeight, "px")
      };
    }

    return null;
  };

  var isTouchable = useCallback(function () {
    return state.status !== 'loading' && state.status !== 'success' && !disabled;
  }, [state.status, disabled]);

  var ease = function ease(distance) {
    var pullDistance = +(props.pullDistance || props.headHeight);

    if (distance > pullDistance) {
      if (distance < pullDistance * 2) {
        distance = pullDistance + (distance - pullDistance) / 2;
      } else {
        distance = pullDistance * 1.5 + (distance - pullDistance * 2) / 4;
      }
    }

    return Math.round(distance);
  };

  var setStatus = function setStatus(distance, isLoading) {
    var pullDistance = +(props.pullDistance || props.headHeight);
    var newState = {
      distance: distance
    };

    if (isLoading) {
      newState.status = 'loading';
    } else if (distance === 0) {
      newState.status = 'normal';
    } else if (distance < pullDistance) {
      newState.status = 'pulling';
    } else {
      newState.status = 'loosing';
    }

    updateState(newState);
  };

  var getStatusText = function getStatusText() {
    if (state.status === 'normal') {
      return '';
    }

    return props["".concat(state.status, "Text")];
  };

  var renderStatus = function renderStatus() {
    var status = state.status,
        distance = state.distance;

    if (typeof props["".concat(state.status, "Text")] === 'function') {
      return props["".concat(state.status, "Text")]({
        distance: distance
      });
    }

    var nodes = [];

    if (TEXT_STATUS.includes(status)) {
      nodes.push( /*#__PURE__*/React.createElement("div", {
        key: "text",
        className: classnames(bem('text'))
      }, getStatusText()));
    }

    if (status === 'loading') {
      nodes.push( /*#__PURE__*/React.createElement(Loading, {
        key: "loading",
        className: classnames(bem('loading'))
      }, getStatusText()));
    }

    return nodes;
  };

  var showSuccessTip = function showSuccessTip() {
    updateState({
      status: 'success'
    });
    setTimeout(function () {
      setStatus(0);
    }, +props.successDuration);
  };

  var onRefresh = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;
              updateState({
                refreshing: true
              });
              _context.next = 4;
              return props.onRefresh();

            case 4:
              updateState({
                refreshing: false
              });
              _context.next = 10;
              break;

            case 7:
              _context.prev = 7;
              _context.t0 = _context["catch"](0);
              updateState({
                refreshing: false
              });

            case 10:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[0, 7]]);
    }));

    return function onRefresh() {
      return _ref.apply(this, arguments);
    };
  }();

  var checkPosition = function checkPosition(event) {
    var scrollTarget = getScrollParent(event.target);
    reachTop.current = getScrollTop(scrollTarget) === 0;

    if (reachTop.current) {
      updateState({
        duration: 0
      });
      touch.start(event);
    }
  };

  var onTouchStart = function onTouchStart(event) {
    if (isTouchable()) {
      checkPosition(event.nativeEvent);
    }
  };

  var onTouchMove = useCallback(function (event) {
    if (isTouchable()) {
      if (!reachTop.current) {
        checkPosition(event);
      }

      touch.move(event);

      if (reachTop.current && touch.deltaY.current >= 0 && touch.isVertical()) {
        setStatus(ease(touch.deltaY.current));
        preventDefault(event);
      } else {
        /**
         * IN THIS CASE:
         * if component don't rerender after event.preventDefault
         * ios will hold `preventDefault` behavior when touchmoving
         * it will cause window unscrollable
         */
        setStatus(0);
      }
    }
  }, [reachTop.current, touch.deltaY, isTouchable]);

  var onTouchEnd = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              if (reachTop.current && touch.deltaY && isTouchable()) {
                updateState({
                  duration: +animationDuration
                });

                if (state.status === 'loosing') {
                  setStatus(+props.headHeight, true);
                  onRefresh();
                } else {
                  setStatus(0);
                }
              }

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    }));

    return function onTouchEnd() {
      return _ref2.apply(this, arguments);
    };
  }();

  useEventListener('touchmove', onTouchMove, {
    target: track.current,
    depends: [reachTop.current, isTouchable(), touch.deltaY]
  });
  useUpdateEffect(function () {
    updateState({
      duration: +animationDuration
    });

    if (state.refreshing) {
      setStatus(+props.headHeight, true);
    } else if (props.successText) {
      showSuccessTip();
    } else {
      setStatus(0, false);
    }
  }, [state.refreshing]);
  var trackStyle = useMemo(function () {
    return {
      transitionDuration: "".concat(state.duration, "ms"),
      transform: state.distance ? "translate3d(0,".concat(state.distance, "px, 0)") : ''
    };
  }, [state.duration, state.distance]);
  return /*#__PURE__*/React.createElement("div", {
    ref: root,
    className: classnames(props.className, bem()),
    style: props.style
  }, /*#__PURE__*/React.createElement("div", {
    ref: track,
    className: classnames(bem('track')),
    style: trackStyle,
    onTouchStart: onTouchStart,
    onTouchEnd: onTouchEnd,
    onTouchCancel: onTouchEnd
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('head')),
    style: getHeadStyle()
  }, renderStatus()), props.children));
};

PullRefresh.defaultProps = {
  headHeight: 50,
  animationDuration: 300,
  successDuration: 500,
  pullingText: '下拉即可刷新...',
  loosingText: '释放即可刷新...',
  loadingText: '加载中...'
};
export default PullRefresh;
